@@ -5,6 +5,19 @@ use namespace::autoclean;
 
 use Template::Mustache;
 
+has 'delimiter' => (
+    is      => 'rw',
+    isa     => 'Str',
+    default => '{',
+);
+
+has 'sample_var' => (
+    is      => 'rw',
+    isa     => 'Str',
+    lazy    => 1,
+    default => '{{{sample}}}',
+);
+
 sub interpol_directive {
     my $self   = shift;
     my $k = shift;
@@ -24,6 +37,11 @@ sub interpol_directive {
 
     $text = Template::Mustache->render( $source, $self );
     $self->interpol_directive_cache->{$source} = $text;
+
+    ##If its the same and it has a $sign, its probably a perl expression
+    if ($text eq $source && $text =~ m/\$/){
+        return $self->interpol_text_template($source);
+    }
     return $text;
 
 }
